@@ -1,8 +1,10 @@
 import logging
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
+from datayoga_core import utils
 from datayoga_core.context import Context
 from datayoga_core.job import Job
+from datayoga_core.result import Result
 
 logger = logging.getLogger("dy")
 
@@ -47,7 +49,8 @@ def validate(job_settings: Dict[str, Any], whitelisted_blocks: Optional[List[str
 
 def transform(job_settings: Dict[str, Any],
               data: List[Dict[str, Any]],
-              context: Optional[Context] = None, whitelisted_blocks: Optional[List[str]] = None) -> List[Dict[str, Any]]:
+              context: Optional[Context] = None,
+              whitelisted_blocks: Optional[List[str]] = None) -> Tuple[List[Dict[str, Any]], List[Result]]:
     """
     Transforms data against a certain job
 
@@ -58,9 +61,14 @@ def transform(job_settings: Dict[str, Any],
         whitelisted_blocks: (Optional[List[str]], optional): Whitelisted blocks. Defaults to None.
 
     Returns:
-        List[Dict[str, Any]]: Transformed data
+        Tuple[List[Dict[str, Any]], List[Result]]: Transformed data and results
     """
     job = compile(job_settings, whitelisted_blocks)
     job.init(context)
     logger.debug("Transforming data")
-    return job.transform(data)
+    try:
+        return job.transform(data)
+    except Exception as e:
+        logger.error(f"Error while transforming data: {e}")
+        utils.reject_records(data, f"{e}")
+        return utils.produce_data_and_results(data)
